==> haskell-pandoc-types-1.16.1-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.16.1
id: pandoc-types-1.16.1-6BIqlHA3W3u4jroqU5TulH
key: pandoc-types-1.16.1-6BIqlHA3W3u4jroqU5TulH
license: BSD3
copyright: (c) 2006-2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.Pandoc.Definition Text.Pandoc.Generic Text.Pandoc.Walk
    Text.Pandoc.Builder Text.Pandoc.JSON
hidden-modules: Paths_pandoc_types
abi: d7ea59b312c88283950cd78e9284fba2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.16.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.16.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/pandoc-types-1.16.1
hs-libraries: HSpandoc-types-1.16.1-6BIqlHA3W3u4jroqU5TulH
depends:
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    ghc-prim-0.5.0.0 syb-0.6-C65vWCsht6A8uLstpQIXyj
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.16.1-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.16.1
id: pandoc-types-1.16.1-EIyaGTPwCLv4krWc2qmdlR
key: pandoc-types-1.16.1-EIyaGTPwCLv4krWc2qmdlR
license: BSD3
copyright: (c) 2006-2015 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.Pandoc.Definition Text.Pandoc.Generic Text.Pandoc.Walk
    Text.Pandoc.Builder Text.Pandoc.JSON
hidden-modules: Paths_pandoc_types
abi: b3a243766b2674509809b36fa8c25f09
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.16.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-types-1.16.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/pandoc-types-1.16.1
hs-libraries: HSpandoc-types-1.16.1-EIyaGTPwCLv4krWc2qmdlR
depends:
    aeson-0.11.2.0-FpCNsdqaa7PINk2PVkQvbE base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    ghc-prim-0.5.0.0 syb-0.6-C65vWCsht6A8uLstpQIXyj
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
